==> org.eclipse.incquery.uml.source_1.1.0.201511122120.jar: org/eclipse/incquery/uml/derivedfeatures/StateIsCompositeMatch.java <==
package org.eclipse.incquery.uml.derivedfeatures;

import java.util.Arrays;
import java.util.List;
import org.eclipse.incquery.runtime.api.IPatternMatch;
import org.eclipse.incquery.runtime.api.impl.BasePatternMatch;
import org.eclipse.incquery.runtime.exception.IncQueryException;
import org.eclipse.incquery.uml.derivedfeatures.util.StateIsCompositeQuerySpecification;
import org.eclipse.uml2.uml.State;

/**
 * Pattern-specific match representation of the org.eclipse.incquery.uml.derivedfeatures.stateIsComposite pattern,
 * to be used in conjunction with {@link StateIsCompositeMatcher}.
 * 
 * <p>Class fields correspond to parameters of the pattern. Fields with value null are considered unassigned.
 * Each instance is a (possibly partial) substitution of pattern parameters,
 * usable to represent a match of the pattern in the result of a query,
 * or to specify the bound (fixed) input parameters when issuing a query.
 * 
 * @see StateIsCompositeMatcher
 * @see StateIsCompositeProcessor
 * 
 */
@SuppressWarnings("all")
public abstract class StateIsCompositeMatch extends BasePatternMatch {
  private State fSelf;
  
  private Boolean fIsComposite;
  
  private static List<String> parameterNames = makeImmutableList("self", "isComposite");
  
  private StateIsCompositeMatch(final State pSelf, final Boolean pIsComposite) {
    this.fSelf = pSelf;
    this.fIsComposite = pIsComposite;
  }
  
  @Override
  public Object get(final String parameterName) {
    if ("self".equals(parameterName)) return this.fSelf;
    if ("isComposite".equals(parameterName)) return this.fIsComposite;
    return null;
  }
  
  public State getSelf() {
    return this.fSelf;
  }
  
  public Boolean getIsComposite() {
    return this.fIsComposite;
  }
  
  @Override
  public boolean set(final String parameterName, final Object newValue) {
    if (!isMutable()) throw new java.lang.UnsupportedOperationException();
    if ("self".equals(parameterName) ) {
    	this.fSelf = (org.eclipse.uml2.uml.State) newValue;
    	return true;
    }
    if ("isComposite".equals(parameterName) ) {
    	this.fIsComposite = (java.lang.Boolean) newValue;
    	return true;
    }
    return false;
  }
  
  public void setSelf(final State pSelf) {
    if (!isMutable()) throw new java.lang.UnsupportedOperationException();
    this.fSelf = pSelf;
  }
  
  public void setIsComposite(final Boolean pIsComposite) {
    if (!isMutable()) throw new java.lang.UnsupportedOperationException();
    this.fIsComposite = pIsComposite;
  }
  
  @Override
  public String patternName() {
    return "org.eclipse.incquery.uml.derivedfeatures.stateIsComposite";
  }
  
  @Override
  public List<String> parameterNames() {
    return StateIsCompositeMatch.parameterNames;
  }
  
  @Override
  public Object[] toArray() {
    return new Object[]{fSelf, fIsComposite};
  }
  
  @Override
  public StateIsCompositeMatch toImmutable() {
    return isMutable() ? newMatch(fSelf, fIsComposite) : this;
  }
  
  @Override
  public String prettyPrint() {
    StringBuilder result = new StringBuilder();
    result.append("\"self\"=" + prettyPrintValue(fSelf) + ", ");
    
    result.append("\"isComposite\"=" + prettyPrintValue(fIsComposite)
    );
    return result.toString();
  }
  
  @Override
  public int hashCode() {
    final int prime = 31;
    int result = 1;
    result = prime * result + ((fSelf == null) ? 0 : fSelf.hashCode());
    result = prime * result + ((fIsComposite == null) ? 0 : fIsComposite.hashCode());
    return result;
  }
  
  @Override
  public boolean equals(final Object obj) {
    if (this == obj)
    	return true;
    if (!(obj instanceof StateIsCompositeMatch)) { // this should be infrequent
    	if (obj == null) {
    		return false;
    	}
    	if (!(obj instanceof IPatternMatch)) {
    		return false;
    	}
    	IPatternMatch otherSig  = (IPatternMatch) obj;
    	if (!specification().equals(otherSig.specification()))
    		return false;
    	return Arrays.deepEquals(toArray(), otherSig.toArray());
    }
    StateIsCompositeMatch other = (StateIsCompositeMatch) obj;
    if (fSelf == null) {if (other.fSelf != null) return false;}
    else if (!fSelf.equals(other.fSelf)) return false;
    if (fIsComposite == null) {if (other.fIsComposite != null) return false;}
    else if (!fIsComposite.equals(other.fIsComposite)) return false;
    return true;
  }
  
  @Override
  public StateIsCompositeQuerySpecification specification() {
    try {
    	return StateIsCompositeQuerySpecification.instance();
    } catch (IncQueryException ex) {
     	// This cannot happen, as the match object can only be instantiated if the query specification exists
     	throw new IllegalStateException (ex);
    }
  }
  
  /**
   * Returns an empty, mutable match.
   * Fields of the mutable match can be filled to create a partial match, usable as matcher input.
   * 
   * @return the empty match.
   * 
   */
  public static StateIsCompositeMatch newEmptyMatch() {
    return new Mutable(null, null);
  }
  
  /**
   * Returns a mutable (partial) match.
   * Fields of the mutable match can be filled to create a partial match, usable as matcher input.
   * 
   * @param pSelf the fixed value of pattern parameter self, or null if not bound.
   * @param pIsComposite the fixed value of pattern parameter isComposite, or null if not bound.
   * @return the new, mutable (partial) match object.
   * 
   */
  public static StateIsCompositeMatch newMutableMatch(final State pSelf, final Boolean pIsComposite) {
    return new Mutable(pSelf, pIsComposite);
  }
  
  /**
   * Returns a new (partial) match.
   * This can be used e.g. to call the matcher with a partial match.
   * <p>The returned match will be immutable. Use {@link #newEmptyMatch()} to obtain a mutable match object.
   * @param pSelf the fixed value of pattern parameter self, or null if not bound.
   * @param pIsComposite the fixed value of pattern parameter isComposite, or null if not bound.
   * @return the (partial) match object.
   * 
   */
  public static StateIsCompositeMatch newMatch(final State pSelf, final Boolean pIsComposite) {
    return new Immutable(pSelf, pIsComposite);
  }
  
  private static final class Mutable extends StateIsCompositeMatch {
    Mutable(final State pSelf, final Boolean pIsComposite) {
      super(pSelf, pIsComposite);
    }
    
    @Override
    public boolean isMutable() {
      return true;
    }
  }
  
  private static final class Immutable extends StateIsCompositeMatch {
    Immutable(final State pSelf, final Boolean pIsComposite) {
      super(pSelf, pIsComposite);
    }
    
    @Override
    public boolean isMutable() {
      return false;
    }
  }
}

==> org.eclipse.incquery.uml.source_1.2.0.201602080945.jar: org/eclipse/incquery/uml/derivedfeatures/StateIsCompositeMatch.java <==
package org.eclipse.incquery.uml.derivedfeatures;

import java.util.Arrays;
import java.util.List;
import org.eclipse.incquery.runtime.api.IPatternMatch;
import org.eclipse.incquery.runtime.api.impl.BasePatternMatch;
import org.eclipse.incquery.runtime.exception.IncQueryException;
import org.eclipse.incquery.uml.derivedfeatures.util.StateIsCompositeQuerySpecification;
import org.eclipse.uml2.uml.State;

/**
 * Pattern-specific match representation of the org.eclipse.incquery.uml.derivedfeatures.stateIsComposite pattern,
 * to be used in conjunction with {@link StateIsCompositeMatcher}.
 * 
 * <p>Class fields correspond to parameters of the pattern. Fields with value null are considered unassigned.
 * Each instance is a (possibly partial) substitution of pattern parameters,
 * usable to represent a match of the pattern in the result of a query,
 * or to specify the bound (fixed) input parameters when issuing a query.
 * 
 * @see StateIsCompositeMatcher
 * @see StateIsCompositeProcessor
 * 
 */
@SuppressWarnings("all")
public abstract class StateIsCompositeMatch extends BasePatternMatch {
  private State fSelf;
  
  private Boolean fIsComposite;
  
  private static List<String> parameterNames = makeImmutableList("self", "isComposite");
  
  private StateIsCompositeMatch(final State pSelf, final Boolean pIsComposite) {
    this.fSelf = pSelf;
    this.fIsComposite = pIsComposite;
  }
  
  @Override
  public Object get(final String parameterName) {
    if ("self".equals(parameterName)) return this.fSelf;
    if ("isComposite".equals(parameterName)) return this.fIsComposite;
    return null;
  }
  
  public State getSelf() {
    return this.fSelf;
  }
  
  public Boolean getIsComposite() {
    return this.fIsComposite;
  }
  
  @Override
  public boolean set(final String parameterName, final Object newValue) {
    if (!isMutable()) throw new java.lang.UnsupportedOperationException();
    if ("self".equals(parameterName) ) {
    	this.fSelf = (State) newValue;
    	return true;
    }
    if ("isComposite".equals(parameterName) ) {
    	this.fIsComposite = (Boolean) newValue;
    	return true;
    }
    return false;
  }
  
  public void setSelf(final State pSelf) {
    if (!isMutable()) throw new java.lang.UnsupportedOperationException();
    this.fSelf = pSelf;
  }
  
  public void setIsComposite(final Boolean pIsComposite) {
    if (!isMutable()) throw new java.lang.UnsupportedOperationException();
    this.fIsComposite = pIsComposite;
  }
  
  @Override
  public String patternName() {
    return "org.eclipse.incquery.uml.derivedfeatures.stateIsComposite";
  }
  
  @Override
  public List<String> parameterNames() {
    return StateIsCompositeMatch.parameterNames;
  }
  
  @Override
  public Object[] toArray() {
    return new Object[]{fSelf, fIsComposite};
  }
  
  @Override
  public StateIsCompositeMatch toImmutable() {
    return isMutable() ? newMatch(fSelf, fIsComposite) : this;
  }
  
  @Override
  public String prettyPrint() {
    StringBuilder result = new StringBuilder();
    result.append("\"self\"=" + prettyPrintValue(fSelf) + ", ");
    
    result.append("\"isComposite\"=" + prettyPrintValue(fIsComposite)
    );
    return result.toString();
  }
  
  @Override
  public int hashCode() {
    final int prime = 31;
    int result = 1;
    result = prime * result + ((fSelf == null) ? 0 : fSelf.hashCode());
    result = prime * result + ((fIsComposite == null) ? 0 : fIsComposite.hashCode());
    return result;
  }
  
  @Override
  public boolean equals(final Object obj) {
    if (this == obj)
    	return true;
    if (!(obj instanceof StateIsCompositeMatch)) { // this should be infrequent
    	if (obj == null) {
    		return false;
    	}
    	if (!(obj instanceof IPatternMatch)) {
    		return false;
    	}
    	IPatternMatch otherSig  = (IPatternMatch) obj;
    	if (!specification().equals(otherSig.specification()))
    		return false;
    	return Arrays.deepEquals(toArray(), otherSig.toArray());
    }
    StateIsCompositeMatch other = (StateIsCompositeMatch) obj;
    if (fSelf == null) {if (other.fSelf != null) return false;}
    else if (!fSelf.equals(other.fSelf)) return false;
    if (fIsComposite == null) {if (other.fIsComposite != null) return false;}
    else if (!fIsComposite.equals(other.fIsComposite)) return false;
    return true;
  }
  
  @Override
  public StateIsCompositeQuerySpecification specification() {
    try {
    	return StateIsCompositeQuerySpecification.instance();
    } catch (IncQueryException ex) {
     	// This cannot happen, as the match object can only be instantiated if the query specification exists
     	throw new IllegalStateException (ex);
    }
  }
  
  /**
   * Returns an empty, mutable match.
   * Fields of the mutable match can be filled to create a partial match, usable as matcher input.
   * 
   * @return the empty match.
   * 
   */
  public static StateIsCompositeMatch newEmptyMatch() {
    return new Mutable(null, null);
  }
  
  /**
   * Returns a mutable (partial) match.
   * Fields of the mutable match can be filled to create a partial match, usable as matcher input.
   * 
   * @param pSelf the fixed value of pattern parameter self, or null if not bound.
   * @param pIsComposite the fixed value of pattern parameter isComposite, or null if not bound.
   * @return the new, mutable (partial) match object.
   * 
   */
  public static StateIsCompositeMatch newMutableMatch(final State pSelf, final Boolean pIsComposite) {
    return new Mutable(pSelf, pIsComposite);
  }
  
  /**
   * Returns a new (partial) match.
   * This can be used e.g. to call the matcher with a partial match.
   * <p>The returned match will be immutable. Use {@link #newEmptyMatch()} to obtain a mutable match object.
   * @param pSelf the fixed value of pattern parameter self, or null if not bound.
   * @param pIsComposite the fixed value of pattern parameter isComposite, or null if not bound.
   * @return the (partial) match object.
   * 
   */
  public static StateIsCompositeMatch newMatch(final State pSelf, final Boolean pIsComposite) {
    return new Immutable(pSelf, pIsComposite);
  }
  
  private static final class Mutable extends StateIsCompositeMatch {
    Mutable(final State pSelf, final Boolean pIsComposite) {
      super(pSelf, pIsComposite);
    }
    
    @Override
    public boolean isMutable() {
      return true;
    }
  }
  
  private static final class Immutable extends StateIsCompositeMatch {
    Immutable(final State pSelf, final Boolean pIsComposite) {
      super(pSelf, pIsComposite);
    }
    
    @Override
    public boolean isMutable() {
      return false;
    }
  }
}
